@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::ReadmeFromPod;
 our $AUTHORITY = 'cpan:FAYLAND';
-$Dist::Zilla::Plugin::ReadmeFromPod::VERSION = '0.33';
+$Dist::Zilla::Plugin::ReadmeFromPod::VERSION = '0.34';
 use Moose;
 use List::Util 1.33 qw( first );
 with 'Dist::Zilla::Role::InstallTool' => { -version => 5 }; # after PodWeaver
@@ -18,7 +18,10 @@ has filename => (
 
 sub _build_filename {
     my $self = shift;
-    $self->zilla->main_module->name;
+    # copied from Dist::Zilla::Plugin::ReadmeAnyFromPod
+    my $pm = $self->zilla->main_module->name;
+    (my $pod = $pm) =~ s/\.pm$/\.pod/;
+    return -e $pod ? $pod : $pm;
 }
 
 has type => (
